#
# spec file for package openrct2
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lib_suffix %{nil}
%ifarch x86_64
  %define lib_suffix 64
%endif
%define title_version 0.1.2
%define title_version_url %{title_version}c
%define objects_version 1.0.13
Name:           openrct2
Version:        0.2.5
Release:        bp153.1.17
Summary:        An open source re-implementation of Roller Coaster Tycoon 2
License:        GPL-3.0-only
Group:          Amusements/Games/Strategy/Other
URL:            https://openrct2.io/
Source0:        https://github.com/OpenRCT2/OpenRCT2/archive/v%{version}/OpenRCT2-%{version}.tar.gz
Source1:        https://github.com/OpenRCT2/title-sequences/archive/v%{title_version_url}/title-sequences-%{title_version_url}.tar.gz
Source2:        https://github.com/OpenRCT2/objects/archive/v%{objects_version}.tar.gz#/objects-%{objects_version}.tar.gz
# https://github.com/OpenRCT2/OpenRCT2/issues/4401#issuecomment-511570036
# PATCH-FIX-OPENSUSE no-werror.patch -- Do not use werror, as wno-clobbered does not work
Patch0:         no-werror.patch
BuildRequires:  cmake >= 3.9
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  glibc-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  shared-mime-info
BuildRequires:  update-desktop-files
BuildRequires:  zip
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(icu-uc) >= 59.0
BuildRequires:  pkgconfig(jansson) >= 2.5
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libpng16)
BuildRequires:  pkgconfig(libzip) >= 1.0
BuildRequires:  pkgconfig(openssl) >= 1.0.0
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(speexdsp)
BuildRequires:  pkgconfig(zlib)
Recommends:     (kdialog or zenity)

%description
An open source clone of RollerCoaster Tycoon 2
that depends on the original game assets. On first
game start it will create a ~/.config/OpenRCT2/config.ini file
where the game_path = "" setting has to be set to a directory
into which the original game has been installed to.

%package titlesequences
Summary:        Titlesequences for openRCT2
Group:          Amusements/Games/Strategy/Other
Requires:       %{name} = %{version}

%description titlesequences
This package contains tilesequences like the original ones
used in RollerCoaster Tycoon 1 and 2.
When using RCT1 sequences, the original RCT1 files have to be installed.

%prep
%setup -q -n OpenRCT2-%{version} -a 1 -a 2
%patch0 -p1

# Remove build time references so build-compare can do its work
sed -i "s/__DATE__/\"openSUSE\"/" src/openrct2/Version.h
sed -i "s/__TIME__/\"Build Service\"/" src/openrct2/Version.h

%build
%cmake -DDOWNLOAD_TITLE_SEQUENCES=OFF -DDOWNLOAD_OBJECTS=OFF
%make_build all
# libopenrct2 is not installed when openrct2 is called by make, so set the LD_LIBRARY_PATH
export LD_LIBRARY_PATH="$LD_LIBRARY_PATH:$(dirname $(find . -name libopenrct2.so))"
%make_build g2
# %%cmake changes directory into "build"
cd ..

# Generate titles from source (zipping as parkseq)
pushd title-sequences-%{title_version_url}/title
  mv -v v%{title_version} openrct2
  rm -rv v*
  for dir in *; do
    pushd "$dir"
    zip -9 -X -r ../"$dir"".parkseq" *
    popd
  done
popd

%install
%cmake_install

mkdir -p '%{buildroot}%{_datadir}/%{name}/title'
cp -v title-sequences-%{title_version_url}/title/*.parkseq "%{buildroot}%{_datadir}/%{name}/title"

mkdir -p '%{buildroot}%{_datadir}/%{name}/object'
cp -vR objects-%{objects_version}/objects/* '%{buildroot}%{_datadir}/%{name}/object'

find '%{buildroot}%{_datadir}/%{name}' -type f -exec chmod 644 \{\} \;

# We do that in the correct docdir in the files section.
rm -rf %{buildroot}%{_datadir}/doc

%fdupes %{buildroot}%{_datadir}/%{name}

%files
%license licence.txt
%doc distribution/changelog.txt distribution/readme.txt
%{_bindir}/openrct2
%{_bindir}/openrct2-cli
%{_libdir}/libopenrct2.so
%{_mandir}/man6/openrct2.6%{?ext_man}
%{_datadir}/openrct2/
%exclude %{_datadir}/openrct2/title/rct*
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/applications/*.desktop
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/openrct2.appdata.xml
%{_datadir}/mime/packages/openrct2.xml

%files titlesequences
%license licence.txt
%{_datadir}/openrct2/title/rct*

%changelog
* Sun Mar 29 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 0.2.5. Many bugfixes since 0.2.3. Check
  https://github.com/OpenRCT2/OpenRCT2/releases for the full list
  New features:
  * Use a random title sequence each time it is shown.
  * Shortcut keys for the Tile Inspector.
  * Transport rides can now be synchronised.
  * Make Track Designs work in multiplayer.
  * Added window for scenery scatter tool
  * Console command to remove all floating objects.
  * Speed is automatically reset to normal upon scenario completion.
  * Remember current group in scenario list window.
  * Increase image list capacity by about 100k units.
  * Increase the number of ride music played
    simultaneously from 2 to 32.
- Drop fix-maybe-uninitialized.patch. Merged upstream.
* Mon Jul 15 2019 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.2.3:
  * Rides can now be simulated with ghost trains during construction.
  * Multi-threaded rendering.
  * Various other bugfixes and improvements.
- Added fix-maybe-uninitialized.patch to fix a gcc warning.
- Added no-werror.patch to build as wno-clobbered does not work
- Install needed object files
  * Fixed boo#1120400
- Splitted optional titlesequences as a subpackage (sequences
  which need RCT1 or RCT2 to be installed).
- Update to version 0.2.2:
  * Allow steep slopes on the side-friction roller coaster.
  * Mulitple glyphs for multiple eastern languages have been added
  * Allow building footpaths on 'corner down' terrain.
  * Allow building on-ride photos and water S-bends on the Water
    Coaster.
  * Add replay system.
  * No longer require the generic scenery groups and tarmac footpath
    to be checked when creating a scenario.
  * Client IP address is logged as `(null)` in server logs.
  * Fixed crash when switching between languages.
  * Fixed desync due to boats colliding with ghost pieces.
  * Removed support for scenario text objects.
  * Various other bugfixes and improvements
* Sun Sep  9 2018 mailaender@opensuse.org
- Update to version 0.2.1
- Drop mime.patch (included upstream)
- Drop appdata.patch (included upstream)
* Sat Aug 12 2017 mailaender@opensuse.org
- Add mime.patch
- Add appdata.patch
* Fri Aug 11 2017 mailaender@opensuse.org
- Update to version 0.1.1
- Drop libsuffix.patch
* Sat Jul 15 2017 mailaender@opensuse.org
- Update to version 0.1.0
- Drop download-title-sequences.patch (applied upstream)
- Don't require SDL2_ttf (not used anymore)
- Add libsuffix.patch
* Tue Feb  7 2017 mailaender@opensuse.org
- Update to version 0.0.6
  * Drop fix-no-real-prototypes.patch (included upstream)
- Fix the title sequences
  * Drop bundled-title-sequences.patch
  * Add download-title-sequences.patch
* Wed Jan 11 2017 rpm@fthiessen.de
- Update to version 0.0.5
  * First version which does not require original exe (just assets)
  * Runs on x64
- Added bundled-title-sequences.patch
- Removed upstream merged patches:
  * 3507.patch
  * 9d1fee2bda3dbbefbf69641876ba6315bcbe6da0.patch
* Sun May  8 2016 mailaender@opensuse.org
- Fix file-contains-date-and-time
* Fri May  6 2016 mailaender@opensuse.org
- update to version 0.0.4
* Wed Dec 30 2015 mailaender@opensuse.org
- initial packaging of version 0.0.3.1
